A simple crate for generating GraphViz dot directed trees,
based on an arbitrary tree structure.
A tree can be any struct that implements:
std::string::ToString, std::hash::Hash and TreeVizNode.
Currently, this crate does not support recursive elements within a tree.
An optional "async" feature is available and provides an async variant of
draw_nodes - draw_nodes_async, which will recurse through a
node’s children concurrently.
This introduces a dependency on the futures crate, but may be quicker,
especially if futures is already in your dependency tree.
Traits
- Tree
VizNode - A trait that represents a node in an arbitrary tree structure. To use this with draw_nodes, you also need to implement std::hash::Hash.
Functions
- draw_
nodes - Returns a visualisation of the tree with the root node
nodein the GraphViz DOT format, as a string.